@@ -1,4 +1,5 @@
-
+import logging
+logger = logging.getLogger(__name__)
 
 def set_dataframe_columntypes(df):
     """Manual setting of the datatypes
@@ -9,7 +10,7 @@ def set_dataframe_columntypes(df):
     Returns:
        df [df]: [Dataframe with the leads information, with the new types]
     """
-    logging.info("Changing data types")
+    logger.info("Changing data types")
     df = clean_rows_with_na( df=df, cols_to_clean_na=['IDEmailStatus'] )
     if 'idLead' in df:
         df['idLead'] = df['idLead'].astype('int32')
@@ -80,7 +81,7 @@ def clean_previous_status(df, status_to_clean):
         df [dataframe]: [dataframe with the leads]
     """
 
-    logging.info(f"Cleaning invalid previous status ( {status_to_clean})")
+    logger.info(f"Cleaning invalid previous status ( {status_to_clean})")
     for status in status_to_clean:
         if 'PreviousStatus' in df:
             df = df[df.PreviousStatus != status]
@@ -95,18 +96,18 @@ def clean_rows_with_na(df,cols_to_clean_na):
     Returns:
         df [dataframe]: [dataframe with the leads]
     """
-    # Logging  amount of rows
+    # logger  amount of rows
     nrows_pre = df.shape[0]
-    logging.info( f"Original rows: {nrows_pre}" )
+    logger.info( f"Original rows: {nrows_pre}" )
 
     for col in cols_to_clean_na:
         if col in df:
             nas_sum = df[col].isna().sum()
-            logging.info(f"NAs in {col}: {nas_sum}")
+            logger.info(f"NAs in {col}: {nas_sum}")
             df = df[df[col].notna()]
     nrows_post = df.shape[0]
     percentage_eliminated = (nrows_pre - nrows_post) / nrows_pre * 100
-    logging.info( f" Rows after deleting rows with NA: {nrows_post}, Percentage: {percentage_eliminated}" )
+    logger.info( f" Rows after deleting rows with NA: {nrows_post}, Percentage: {percentage_eliminated}" )
 
     return df
 
@@ -121,7 +122,7 @@ def fill_na_with_unknown(df, columns):
     """
     for col in columns:
         if col in df.columns:
-            logging.info(f'filling NA in {col} with "unknown" ')
+            logger.info(f'filling NA in {col} with "unknown" ')
             df[col] = df[col].fillna('Unknown')
     return df
 
@@ -134,7 +135,7 @@ def create_specialties_flag(df):
     Returns:
         df ([dataframe]): Dataframe with leads
     """
-    logging.info("Creating Specialties flag")
+    logger.info("Creating Specialties flag")
     df['Has Specialties'] = df['Specialties'].isna()
     df['Has Specialties'] *= 1
     df['Has Specialties'] = df['Has Specialties'].astype("category")
@@ -144,23 +145,23 @@ def create_specialties_flag(df):
 def set_idemailstatus_target_column(df):
 
     if ('IDEmailStatus' in df.columns):
-        logging.info('Setting E-Mail status target ')
+        logger.info('Setting E-Mail status target ')
         df = df[~df['IDEmailStatus'].isin([3, 5, 7, 32])]
         df.loc[df['IDEmailStatus'] != 14, 'IDEmailStatus'] = 0
         df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
     else:
-        logging.error('No IDEmailSTatus column found')
+        logger.error('No IDEmailSTatus column found')
         raise Exception('No IDEmailStatus column found!!!!!')
     return df
 
 
 def set_bv_target_column(df):
     if('BV' in df.columns):
-        logging.info('Setting BV status target ')
+        logger.info('Setting BV status target ')
         df = df[df.BV.notna()]
         df['BV']=df['BV'].astype('float32')
     else:
-        logging.error('No BV column found')
+        logger.error('No BV column found')
         raise Exception('No BV column found!!!!!')
     #   df = df[df.BV < 40]
     return df
@@ -168,12 +169,12 @@ def set_bv_target_column(df):
 
 def set_bv_discrete_target_column(df,bins):
     if('BV' in df.columns):
-        logging.info('Setting BV status target for classification ')
+        logger.info('Setting BV status target for classification ')
         df.BV.fillna(value=0,inplace=True)
         labels = [0, 1, 2, 3, 4, 5]
         df.insert(loc=1,column='BV_cut', value= pd.cut(x=df['BV'], bins = bins,labels=labels).astype('float32'))
     else:
-        logging.error('No BV column found')
+        logger.error('No BV column found')
         raise Exception('No BV column found!!!!!')
     return df
 
@@ -198,7 +199,7 @@ def create_company_years_column(df):
         df [dataframe]: [dataframe with the leads]
     """
 
-    logging.info("Creating company years category")
+    logger.info("Creating company years category")
     # Create Company years category
     if df['YearFounded'].dtype == object:
         df['YearFounded'] = df['YearFounded'].str.extract(
@@ -235,7 +236,7 @@ def fill_seniority_column(df):
     Returns:
         df [datafrane]: [dataframe with the leads]
     """
-    logging.info("Filling Seniority from some Titles")
+    logger.info("Filling Seniority from some Titles")
     df.loc[(df['Title'].str.contains('Specialist', 'Title')) &
            (df['Seniority'].isna()), 'Seniority'] = 'Specialist'
     df.loc[(df['Title'].str.contains('Associate', 'Title')) &
@@ -246,7 +247,7 @@ def fill_seniority_column(df):
 
 
 def filter_countries(df, countries):
-    logging.info(f'Filtering the following countries: {countries}')
+    logger.info(f'Filtering the following countries: {countries}')
     df = df[df['Country'].isin(countries)]
     return df
 
@@ -260,15 +261,15 @@ def convert_kwkey_specialties_and_technologies_to_int(df):
     Returns:
        df [dataframe]: [Dataframe with the leads]
     """
-    logging.info(f'Counting KeyWords')
+    logger.info(f'Counting KeyWords')
     # number of elements in kw_key
     df['Nkw_key'] = df.kw_key.apply(
         lambda x: 0 if pd.isnull(x) else len(re.findall("(?:\".*?\"|\S)+", x)))
     # Number of elements in technologies
-    logging.info( f'Counting Technologies' )
+    logger.info( f'Counting Technologies' )
     df['NTechnologies'] = df.Technologies.apply(
         lambda x: 0 if pd.isnull(x) else len(re.split(',', x)))
-    logging.info( f'Counting Specialties' )
+    logger.info( f'Counting Specialties' )
     df['NSpecialties'] = df.Technologies.apply(
         lambda x: 0 if pd.isnull(x) else len(re.split(',', x)))
 
@@ -283,7 +284,7 @@ def fill_historic_variables(df):
     Returns:
         df [dataframe]: [Dataframe with the leads]
     """
-    logging.info(
+    logger.info(
         "Filling historic variables ( PContacts, PStatus,Daysince last and first contact)")
     if 'PreviousContacts' in df:
         df['PreviousContacts'] = df['PreviousContacts'].fillna(0)
@@ -300,12 +301,12 @@ def fill_historic_variables(df):
 
 def impute_nas_and_save_imputer(df,columns_to_impute):
     df_impute = df[columns_to_impute]
-    logging.info(f"Imputing NAs in {columns_to_impute}")
-    logging.info(f"NAs in DataFrame before imputation:")
+    logger.info(f"Imputing NAs in {columns_to_impute}")
+    logger.info(f"NAs in DataFrame before imputation:")
     nna = df_impute.isna().sum()
-    logging.info(f"{nna}")
+    logger.info(f"{nna}")
 
-    logging.info("No imputer provided, instancing and fitting a new one")
+    logger.info("No imputer provided, instancing and fitting a new one")
     imp = IterativeImputer(missing_values=np.nan,
                             sample_posterior=False,
                             max_iter=10,
@@ -314,13 +315,13 @@ def impute_nas_and_save_imputer(df,columns_to_impute):
                             estimator=BayesianRidge())
 
     imp.fit(df_impute)
-    logging.info("Creating new imputer")
+    logger.info("Creating new imputer")
     df_impute = pd.DataFrame(data=imp.transform(df_impute),
                              columns=df_impute.columns)
 
-    logging.info(f"NAs in DataFrame after imputation:")
+    logger.info(f"NAs in DataFrame after imputation:")
     nna = df_impute.isna().sum()
-    logging.info(f"{nna}")
+    logger.info(f"{nna}")
 
     # Assign column
     for column in columns_to_impute:
@@ -342,19 +343,19 @@ def impute_nas(df,columns_to_impute,imp):
         df [dataframe]: [Dataframe with the leads]
     """
     df_impute = df[columns_to_impute]
-    logging.info(f"Imputing NAs in {columns_to_impute}")
-    logging.info(f"NAs in DataFrame before imputation:")
+    logger.info(f"Imputing NAs in {columns_to_impute}")
+    logger.info(f"NAs in DataFrame before imputation:")
     nna = df_impute.isna().sum()
-    logging.info(f"{nna}")
+    logger.info(f"{nna}")
     # Instance the imputer if it is not created
 
     print("Using provided imputer")
     df_impute = pd.DataFrame(data=imp.transform(df_impute),
                              columns=df_impute.columns)
 
-    logging.info(f"NAs in DataFrame after imputation:")
+    logger.info(f"NAs in DataFrame after imputation:")
     nna = df_impute.isna().sum()
-    logging.info(f"{nna}")
+    logger.info(f"{nna}")
 
     # Assign column
     for column in columns_to_impute:
@@ -374,14 +375,14 @@ def log_transformation(df, columns):
         df ([dataframe]): [datafram with the leads]
     """
     for column in columns:
-        logging.info(f'Log Transforming : {column}')
+        logger.info(f'Log Transforming : {column}')
         df.loc[(df[column] < 0), column] = df[column].mean()
         df[column] = df[column].apply(lambda x: np.log10(x + 1))
     return df
 
 
 def create_month_status(df):
-    logging.info("Creating Month of the date column")
+    logger.info("Creating Month of the date column")
     if 'campaign_bulk_date' in df.columns:
 
         df['MonthStatus'] = pd.DatetimeIndex(
@@ -415,10 +416,10 @@ def clean_mxtype(df,mxtypes):
 
     if 'MXtype' not in df.columns:
         raise Exception ("MXtype column not preset ( Check Caps)")
-    logging.info('Defining MXTypes')
-    logging.info(f'legal MXTypes: {mxtypes}')
+    logger.info('Defining MXTypes')
+    logger.info(f'legal MXTypes: {mxtypes}')
     df.loc[~df['MXtype'].isin(mxtypes), 'MXtype'] = 'Others'
-    logging.info(f'{df.MXtype.value_counts()}')
+    logger.info(f'{df.MXtype.value_counts()}')
     return df
 
 
@@ -433,11 +434,11 @@ def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
 
     if 'MXtype' not in df.columns:
         raise Exception ("MXtype column not preset ( Check Caps)")
-    logging.info('Defining MXTypes')
+    logger.info('Defining MXTypes')
     df['mx_bv'] = df['MXtype']
     df = df.replace({'mx_bv': mx_bv_dict})
-    logging.info(f'{df.mx_bv.value_counts()}')
+    logger.info(f'{df.mx_bv.value_counts()}')
     df['mx_prob'] = df['MXtype']
     df = df.replace( {'mx_prob': mx_prob_dict} )
-    logging.info(f'{df.mx_prob.value_counts()}')
+    logger.info(f'{df.mx_prob.value_counts()}')
     return df
